# UI/UX Feedback

**ID:** Feedback-20260304-105440
**URL:** http://127.0.0.1:5858/
**Date:** 2026-03-04 10:55:33

## Selected Elements

- `{'selector': 'span.workplace-tree-name', 'parents': ['div#workplace-tree', 'ul.workplace-tree-list.workplace-tree-root', 'li.workplace-tree-item.tree-item', 'div.workplace-tree-item-content.idea-folder-node']}`

## Feedback

for idea folder created by workflow, now the name all start with wf-001, it should be incremental

## Screenshot

![Screenshot](x-ipe-docs/uiux-feedback/Feedback-20260304-105440/page-screenshot.png)
